# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ClassificationSpecificEnum(str, Enum):
    """
    
    """

    """
    allowed enum values
    """
    CSX = 'csx'
    CS = 'cs'
    HTML = 'html'
    HTM = 'htm'
    SHTML = 'shtml'
    XHTML = 'xhtml'
    HS = 'hs'
    HS_MINUS_BOOT = 'hs-boot'
    HSIG = 'hsig'
    CPP = 'cpp'
    CC = 'cc'
    CP = 'cp'
    CXX = 'cxx'
    C = 'c'
    H = 'h'
    HH = 'hh'
    HPP = 'hpp'
    HXX = 'hxx'
    INL = 'inl'
    IPP = 'ipp'
    IXX = 'ixx'
    CPPM = 'cppm'
    CSV = 'csv'
    DOC = 'doc'
    DOCM = 'docm'
    DOCX = 'docx'
    EXE = 'exe'
    GIF = 'gif'
    ICO = 'ico'
    JPE = 'jpe'
    JPEG = 'jpeg'
    JPG = 'jpg'
    JPGM = 'jpgm'
    JPGV = 'jpgv'
    LOG = 'log'
    MP2 = 'mp2'
    MP2A = 'mp2a'
    MP3 = 'mp3'
    MP4 = 'mp4'
    MP4A = 'mp4a'
    OGA = 'oga'
    OGG = 'ogg'
    OGV = 'ogv'
    OGX = 'ogx'
    PPT = 'ppt'
    PPTX = 'pptx'
    PPTM = 'pptm'
    QT = 'qt'
    TEXT = 'text'
    TIF = 'tif'
    TIFF = 'tiff'
    TXT = 'txt'
    WAV = 'wav'
    WEBA = 'weba'
    WEBM = 'webm'
    WEBP = 'webp'
    XLA = 'xla'
    XLAM = 'xlam'
    XLC = 'xlc'
    XLM = 'xlm'
    XLS = 'xls'
    XLSB = 'xlsb'
    XLSM = 'xlsm'
    XLSX = 'xlsx'
    XLT = 'xlt'
    XLTM = 'xltm'
    XLTX = 'xltx'
    PDF = 'pdf'
    PNG = 'png'
    RPM = 'rpm'
    ZIP = 'zip'
    WOFF = 'woff'
    WOFF2 = 'woff2'
    SVGZ = 'svgz'
    BIN = 'bin'
    BMP = 'bmp'
    EOT = 'eot'
    GZ = 'gz'
    JAR = 'jar'
    MPKG = 'mpkg'
    AI = 'ai'
    EPS = 'eps'
    DMG = 'dmg'
    LIST = 'list'
    RTX = 'rtx'
    URI = 'uri'
    URIS = 'uris'
    URLS = 'urls'
    CSS = 'css'
    DART = 'dart'
    JAVA = 'java'
    BSH = 'bsh'
    JS = 'js'
    JSX = 'jsx'
    MJS = 'mjs'
    HTC = 'htc'
    JSON = 'json'
    IPYNB = 'ipynb'
    GLTF = 'gltf'
    JSONML = 'jsonml'
    PS = 'ps'
    SSML = 'ssml'
    WASM = 'wasm'
    RTF = 'rtf'
    CCO = 'cco'
    PL = 'pl'
    PC = 'pc'
    PM = 'pm'
    PMC = 'pmc'
    POD = 'pod'
    T = 't'
    XML = 'xml'
    TLD = 'tld'
    DTML = 'dtml'
    RNG = 'rng'
    RSS = 'rss'
    OPML = 'opml'
    SVG = 'svg'
    XAML = 'xaml'
    SUBLIME_MINUS_SNIPPET = 'sublime-snippet'
    TMLANGUAGE = 'tmLanguage'
    TMPREFERENCES = 'tmPreferences'
    TMSNIPPET = 'tmSnippet'
    TMTHEME = 'tmTheme'
    CSPROJ = 'csproj'
    FSPROJ = 'fsproj'
    SQLPROJ = 'sqlproj'
    VBPROJ = 'vbproj'
    VCPROJ = 'vcproj'
    VCXPROJ = 'vcxproj'
    DAE = 'dae'
    PROPS = 'props'
    TARGETS = 'targets'
    XSD = 'xsd'
    XSL = 'xsl'
    XSLT = 'xslt'
    ECMA = 'ecma'
    NODE = 'node'
    PHP = 'php'
    PHP3 = 'php3'
    PHP4 = 'php4'
    PHP5 = 'php5'
    PHP7 = 'php7'
    PHP8 = 'php8'
    PHPS = 'phps'
    PHPT = 'phpt'
    PHTML = 'phtml'
    PY = 'py'
    PY3 = 'py3'
    PYW = 'pyw'
    PYI = 'pyi'
    PYX = 'pyx'
    PYX_DOT_IN = 'pyx.in'
    PXD = 'pxd'
    PXD_DOT_IN = 'pxd.in'
    PXI = 'pxi'
    PXI_DOT_IN = 'pxi.in'
    RPY = 'rpy'
    CPY = 'cpy'
    GYP = 'gyp'
    GYPI = 'gypi'
    VPY = 'vpy'
    SMK = 'smk'
    WSCRIPT = 'wscript'
    BAZEL = 'bazel'
    BZL = 'bzl'
    PYC = 'pyc'
    CLASS = 'class'
    P = 'p'
    PAS = 'pas'
    CURL = 'curl'
    MCURL = 'mcurl'
    GO = 'go'
    SWIFT = 'swift'
    RS = 'rs'
    TS = 'ts'
    TSX = 'tsx'
    RB = 'rb'
    RBI = 'rbi'
    RBX = 'rbx'
    RJS = 'rjs'
    RABL = 'rabl'
    RAKE = 'rake'
    CAPFILE = 'capfile'
    JBUILDER = 'jbuilder'
    GEMSPEC = 'gemspec'
    PODSPEC = 'podspec'
    IRBRC = 'irbrc'
    PRYRC = 'pryrc'
    PRAWN = 'prawn'
    THOR = 'thor'
    APPFILE = 'Appfile'
    APPRAISALS = 'Appraisals'
    BERKSFILE = 'Berksfile'
    BREWFILE = 'Brewfile'
    CHEFFILE = 'Cheffile'
    DELIVERFILE = 'Deliverfile'
    FASTFILE = 'Fastfile'
    GEMFILE = 'Gemfile'
    GUARDFILE = 'Guardfile'
    PODFILE = 'Podfile'
    RAKEFILE = 'Rakefile'
    RANTFILE = 'Rantfile'
    SCANFILE = 'Scanfile'
    SIMPLECOV = 'simplecov'
    SNAPFILE = 'Snapfile'
    THORFILE = 'Thorfile'
    VAGRANTFILE = 'Vagrantfile'
    SCALA = 'scala'
    SBT = 'sbt'
    SC = 'sc'
    CMD = 'cmd'
    BAT = 'bat'
    COFFEE = 'coffee'
    ERL = 'erl'
    HRL = 'hrl'
    ESCRIPT = 'escript'
    LUA = 'lua'
    LUAU = 'luau'
    MD = 'md'
    MDOWN = 'mdown'
    MDWN = 'mdwn'
    MARKDOWN = 'markdown'
    MARKDN = 'markdn'
    MATLAB = 'matlab'
    M = 'm'
    PS1 = 'ps1'
    SH = 'sh'
    BASH = 'bash'
    BASHRC = 'bashrc'
    ASH = 'ash'
    ZSH = 'zsh'
    DOT_BASH_ALIASES = '.bash_aliases'
    DOT_BASH_COMPLETIONS = '.bash_completions'
    DOT_BASH_FUNCTIONS = '.bash_functions'
    DOT_BASH_LOGIN = '.bash_login'
    DOT_BASH_LOGOUT = '.bash_logout'
    DOT_BASH_PROFILE = '.bash_profile'
    DOT_BASH_VARIABLES = '.bash_variables'
    DOT_PROFILE = '.profile'
    DOT_TEXTMATE_INIT = '.textmate_init'
    DOT_ZLOGIN = '.zlogin'
    DOT_ZLOGOUT = '.zlogout'
    DOT_ZPROFILE = '.zprofile'
    DOT_ZSHENV = '.zshenv'
    DOT_ZSHRC = '.zshrc'
    PKGBUILD = 'PKGBUILD'
    EBUILD = 'ebuild'
    ECLASS = 'eclass'
    R = 'r'
    SQL = 'sql'
    DDL = 'ddl'
    DML = 'dml'
    TEX = 'tex'
    LTX = 'ltx'
    STY = 'sty'
    CLS = 'cls'
    UNKNOWN = 'UNKNOWN'
    YAML = 'yaml'
    YML = 'yml'
    TOML = 'toml'
    TML = 'tml'
    CARGO_DOT_LOCK = 'Cargo.lock'
    GOPKG_DOT_LOCK = 'Gopkg.lock'
    PIPFILE = 'Pipfile'
    POETRY_DOT_LOCK = 'poetry.lock'
    UNIFORM_RESOURCE_LOCATOR = 'uniform_resource_locator'
    CUSTOM_URL_SCHEME = 'custom_url_scheme'
    UNIX_FILE_PATH = 'unix_file_path'
    WINDOWS_FILE_PATH = 'windows_file_path'
    UNIFORM_RESOURCE_IDENTIFIER = 'uniform_resource_identifier'
    HLJS_MINUS_1C = 'hljs-1c'
    HLJS_MINUS_ABNF = 'hljs-abnf'
    HLJS_MINUS_ACCESSLOG = 'hljs-accesslog'
    HLJS_MINUS_ACTIONSCRIPT = 'hljs-actionscript'
    HLJS_MINUS_ADA = 'hljs-ada'
    HLJS_MINUS_ANGELSCRIPT = 'hljs-angelscript'
    HLJS_MINUS_APACHE = 'hljs-apache'
    HLJS_MINUS_APPLESCRIPT = 'hljs-applescript'
    HLJS_MINUS_ARCADE = 'hljs-arcade'
    HLJS_MINUS_ARDUINO = 'hljs-arduino'
    HLJS_MINUS_ARMASM = 'hljs-armasm'
    HLJS_MINUS_ASCIIDOC = 'hljs-asciidoc'
    HLJS_MINUS_ASPECTJ = 'hljs-aspectj'
    HLJS_MINUS_AUTOHOTKEY = 'hljs-autohotkey'
    HLJS_MINUS_AUTOIT = 'hljs-autoit'
    HLJS_MINUS_AVRASM = 'hljs-avrasm'
    HLJS_MINUS_AWK = 'hljs-awk'
    HLJS_MINUS_AXAPTA = 'hljs-axapta'
    HLJS_MINUS_BASH = 'hljs-bash'
    HLJS_MINUS_BASIC = 'hljs-basic'
    HLJS_MINUS_BNF = 'hljs-bnf'
    HLJS_MINUS_BRAINFUCK = 'hljs-brainfuck'
    HLJS_MINUS_CAL = 'hljs-cal'
    HLJS_MINUS_CAPNPROTO = 'hljs-capnproto'
    HLJS_MINUS_CEYLON = 'hljs-ceylon'
    HLJS_MINUS_CLEAN = 'hljs-clean'
    HLJS_MINUS_CLOJURE_MINUS_REPL = 'hljs-clojure-repl'
    HLJS_MINUS_CLOJURE = 'hljs-clojure'
    HLJS_MINUS_CMAKE = 'hljs-cmake'
    HLJS_MINUS_COFFEESCRIPT = 'hljs-coffeescript'
    HLJS_MINUS_COQ = 'hljs-coq'
    HLJS_MINUS_COS = 'hljs-cos'
    HLJS_MINUS_CPP = 'hljs-cpp'
    HLJS_MINUS_CRMSH = 'hljs-crmsh'
    HLJS_MINUS_CRYSTAL = 'hljs-crystal'
    HLJS_MINUS_C = 'hljs-c'
    HLJS_MINUS_CS = 'hljs-cs'
    HLJS_MINUS_CSP = 'hljs-csp'
    HLJS_MINUS_CSS = 'hljs-css'
    HLJS_MINUS_D = 'hljs-d'
    HLJS_MINUS_DART = 'hljs-dart'
    HLJS_MINUS_DELPHI = 'hljs-delphi'
    HLJS_MINUS_DIFF = 'hljs-diff'
    HLJS_MINUS_DJANGO = 'hljs-django'
    HLJS_MINUS_DNS = 'hljs-dns'
    HLJS_MINUS_DOCKERFILE = 'hljs-dockerfile'
    HLJS_MINUS_DOS = 'hljs-dos'
    HLJS_MINUS_DSCONFIG = 'hljs-dsconfig'
    HLJS_MINUS_DTS = 'hljs-dts'
    HLJS_MINUS_DUST = 'hljs-dust'
    HLJS_MINUS_EBNF = 'hljs-ebnf'
    HLJS_MINUS_ELIXIR = 'hljs-elixir'
    HLJS_MINUS_ELM = 'hljs-elm'
    HLJS_MINUS_ERB = 'hljs-erb'
    HLJS_MINUS_ERLANG_MINUS_REPL = 'hljs-erlang-repl'
    HLJS_MINUS_ERLANG = 'hljs-erlang'
    HLJS_MINUS_EXCEL = 'hljs-excel'
    HLJS_MINUS_FIX = 'hljs-fix'
    HLJS_MINUS_FLIX = 'hljs-flix'
    HLJS_MINUS_FORTRAN = 'hljs-fortran'
    HLJS_MINUS_FSHARP = 'hljs-fsharp'
    HLJS_MINUS_GAMS = 'hljs-gams'
    HLJS_MINUS_GAUSS = 'hljs-gauss'
    HLJS_MINUS_GCODE = 'hljs-gcode'
    HLJS_MINUS_GHERKIN = 'hljs-gherkin'
    HLJS_MINUS_GLSL = 'hljs-glsl'
    HLJS_MINUS_GML = 'hljs-gml'
    HLJS_MINUS_GO = 'hljs-go'
    HLJS_MINUS_GOLO = 'hljs-golo'
    HLJS_MINUS_GRADLE = 'hljs-gradle'
    HLJS_MINUS_GROOVY = 'hljs-groovy'
    HLJS_MINUS_HAML = 'hljs-haml'
    HLJS_MINUS_HANDLEBARS = 'hljs-handlebars'
    HLJS_MINUS_HASKELL = 'hljs-haskell'
    HLJS_MINUS_HAXE = 'hljs-haxe'
    HLJS_MINUS_HSP = 'hljs-hsp'
    HLJS_MINUS_HTMLBARS = 'hljs-htmlbars'
    HLJS_MINUS_HTTP = 'hljs-http'
    HLJS_MINUS_HY = 'hljs-hy'
    HLJS_MINUS_INFORM7 = 'hljs-inform7'
    HLJS_MINUS_INI = 'hljs-ini'
    HLJS_MINUS_IRPF90 = 'hljs-irpf90'
    HLJS_MINUS_ISBL = 'hljs-isbl'
    HLJS_MINUS_JAVA = 'hljs-java'
    HLJS_MINUS_JAVASCRIPT = 'hljs-javascript'
    HLJS_MINUS_JBOSS_MINUS_CLI = 'hljs-jboss-cli'
    HLJS_MINUS_JSON = 'hljs-json'
    HLJS_MINUS_JULIA_MINUS_REPL = 'hljs-julia-repl'
    HLJS_MINUS_JULIA = 'hljs-julia'
    HLJS_MINUS_KOTLIN = 'hljs-kotlin'
    HLJS_MINUS_LASSO = 'hljs-lasso'
    HLJS_MINUS_LDIF = 'hljs-ldif'
    HLJS_MINUS_LEAF = 'hljs-leaf'
    HLJS_MINUS_LESS = 'hljs-less'
    HLJS_MINUS_LISP = 'hljs-lisp'
    HLJS_MINUS_LIVECODESERVER = 'hljs-livecodeserver'
    HLJS_MINUS_LIVESCRIPT = 'hljs-livescript'
    HLJS_MINUS_LLVM = 'hljs-llvm'
    HLJS_MINUS_LSL = 'hljs-lsl'
    HLJS_MINUS_LUA = 'hljs-lua'
    HLJS_MINUS_MAKEFILE = 'hljs-makefile'
    HLJS_MINUS_MARKDOWN = 'hljs-markdown'
    HLJS_MINUS_MATHEMATICA = 'hljs-mathematica'
    HLJS_MINUS_MATLAB = 'hljs-matlab'
    HLJS_MINUS_MAXIMA = 'hljs-maxima'
    HLJS_MINUS_MEL = 'hljs-mel'
    HLJS_MINUS_MERCURY = 'hljs-mercury'
    HLJS_MINUS_MIPSASM = 'hljs-mipsasm'
    HLJS_MINUS_MIZAR = 'hljs-mizar'
    HLJS_MINUS_MOJOLICIOUS = 'hljs-mojolicious'
    HLJS_MINUS_MONKEY = 'hljs-monkey'
    HLJS_MINUS_MOONSCRIPT = 'hljs-moonscript'
    HLJS_MINUS_N1QL = 'hljs-n1ql'
    HLJS_MINUS_NGINX = 'hljs-nginx'
    HLJS_MINUS_NIMROD = 'hljs-nimrod'
    HLJS_MINUS_NIX = 'hljs-nix'
    HLJS_MINUS_NSIS = 'hljs-nsis'
    HLJS_MINUS_OBJECTIVEC = 'hljs-objectivec'
    HLJS_MINUS_OCAML = 'hljs-ocaml'
    HLJS_MINUS_OPENSCAD = 'hljs-openscad'
    HLJS_MINUS_OXYGENE = 'hljs-oxygene'
    HLJS_MINUS_PARSER3 = 'hljs-parser3'
    HLJS_MINUS_PERL = 'hljs-perl'
    HLJS_MINUS_PF = 'hljs-pf'
    HLJS_MINUS_PGSQL = 'hljs-pgsql'
    HLJS_MINUS_PHP = 'hljs-php'
    HLJS_MINUS_PLAINTEXT = 'hljs-plaintext'
    HLJS_MINUS_PONY = 'hljs-pony'
    HLJS_MINUS_POWERSHELL = 'hljs-powershell'
    HLJS_MINUS_PROCESSING = 'hljs-processing'
    HLJS_MINUS_PROFILE = 'hljs-profile'
    HLJS_MINUS_PROLOG = 'hljs-prolog'
    HLJS_MINUS_PROPERTIES = 'hljs-properties'
    HLJS_MINUS_PROTOBUF = 'hljs-protobuf'
    HLJS_MINUS_PUPPET = 'hljs-puppet'
    HLJS_MINUS_PUREBASIC = 'hljs-purebasic'
    HLJS_MINUS_PYTHON = 'hljs-python'
    HLJS_MINUS_Q = 'hljs-q'
    HLJS_MINUS_QML = 'hljs-qml'
    HLJS_MINUS_R = 'hljs-r'
    HLJS_MINUS_REASONML = 'hljs-reasonml'
    HLJS_MINUS_RIB = 'hljs-rib'
    HLJS_MINUS_ROBOCONF = 'hljs-roboconf'
    HLJS_MINUS_ROUTEROS = 'hljs-routeros'
    HLJS_MINUS_RSL = 'hljs-rsl'
    HLJS_MINUS_RUBY = 'hljs-ruby'
    HLJS_MINUS_RULESLANGUAGE = 'hljs-ruleslanguage'
    HLJS_MINUS_RUST = 'hljs-rust'
    HLJS_MINUS_SAS = 'hljs-sas'
    HLJS_MINUS_SCALA = 'hljs-scala'
    HLJS_MINUS_SCHEME = 'hljs-scheme'
    HLJS_MINUS_SCILAB = 'hljs-scilab'
    HLJS_MINUS_SCSS = 'hljs-scss'
    HLJS_MINUS_SHELL = 'hljs-shell'
    HLJS_MINUS_SMALI = 'hljs-smali'
    HLJS_MINUS_SMALLTALK = 'hljs-smalltalk'
    HLJS_MINUS_SML = 'hljs-sml'
    HLJS_MINUS_SQF = 'hljs-sqf'
    HLJS_MINUS_SQL = 'hljs-sql'
    HLJS_MINUS_STAN = 'hljs-stan'
    HLJS_MINUS_STATA = 'hljs-stata'
    HLJS_MINUS_STEP21 = 'hljs-step21'
    HLJS_MINUS_STYLUS = 'hljs-stylus'
    HLJS_MINUS_SUBUNIT = 'hljs-subunit'
    HLJS_MINUS_SWIFT = 'hljs-swift'
    HLJS_MINUS_TAGGERSCRIPT = 'hljs-taggerscript'
    HLJS_MINUS_TAP = 'hljs-tap'
    HLJS_MINUS_TCL = 'hljs-tcl'
    HLJS_MINUS_TEX = 'hljs-tex'
    HLJS_MINUS_THRIFT = 'hljs-thrift'
    HLJS_MINUS_TP = 'hljs-tp'
    HLJS_MINUS_TWIG = 'hljs-twig'
    HLJS_MINUS_TYPESCRIPT = 'hljs-typescript'
    HLJS_MINUS_VALA = 'hljs-vala'
    HLJS_MINUS_VBNET = 'hljs-vbnet'
    HLJS_MINUS_VBSCRIPT_MINUS_HTML = 'hljs-vbscript-html'
    HLJS_MINUS_VBSCRIPT = 'hljs-vbscript'
    HLJS_MINUS_VERILOG = 'hljs-verilog'
    HLJS_MINUS_VHDL = 'hljs-vhdl'
    HLJS_MINUS_VIM = 'hljs-vim'
    HLJS_MINUS_X86ASM = 'hljs-x86asm'
    HLJS_MINUS_XL = 'hljs-xl'
    HLJS_MINUS_XML = 'hljs-xml'
    HLJS_MINUS_XQUERY = 'hljs-xquery'
    HLJS_MINUS_YAML = 'hljs-yaml'
    HLJS_MINUS_TOML = 'hljs-toml'
    HLJS_MINUS_ZEPHIR = 'hljs-zephir'
    HLJS_MINUS_HTML = 'hljs-html'
    GROOVY = 'groovy'
    KT = 'kt'
    EL = 'el'
    CLJ = 'clj'
    EX = 'ex'
    ADB = 'adb'
    ADS = 'ads'
    AGDA = 'agda'
    ELM = 'elm'
    EXS = 'exs'
    GLSL = 'glsl'
    ML = 'ml'
    LEAN = 'lean'
    LISP = 'lisp'
    RKT = 'rkt'
    SPARQL = 'sparql'
    VHDL = 'vhdl'
    ZIG = 'zig'
    DOCKERFILE = 'dockerfile'
    F03 = 'f03'
    F08 = 'f08'
    F18 = 'f18'
    F90 = 'f90'
    F95 = 'f95'
    JL = 'jl'
    MM = 'mm'
    SCM = 'scm'
    SOL = 'sol'
    SV = 'sv'
    ASP = 'asp'
    CFM = 'cfm'
    FS = 'fs'
    FSI = 'fsi'
    FSX = 'fsx'
    TF = 'tf'
    VBA = 'vba'
    SVELTE = 'svelte'
    VUE = 'vue'
    SCSS = 'scss'
    FEATURE = 'feature'
    INI = 'ini'
    FTL = 'ftl'
    HCL = 'hcl'
    ABAP = 'abap'
    NIM = 'nim'

    @classmethod
    def from_json(cls, json_str: str) -> ClassificationSpecificEnum:
        """Create an instance of ClassificationSpecificEnum from a JSON string"""
        return ClassificationSpecificEnum(json.loads(json_str))





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field
from pieces_os_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_os_client.models.seeded_tracked_adoption_event import SeededTrackedAdoptionEvent
from pieces_os_client.models.seeded_tracked_interaction_event import SeededTrackedInteractionEvent
from pieces_os_client.models.seeded_tracked_keyboard_event import SeededTrackedKeyboardEvent
from pieces_os_client.models.seeded_tracked_machine_learning_event import SeededTrackedMachineLearningEvent
from pieces_os_client.models.seeded_tracked_session_event import SeededTrackedSessionEvent

class SeededConnectorTracking(BaseModel):
    """
    This model is designed to be light weight and low friction while most of the heavy lifting will be happening inside of the context servers.  This Model is important because this has references to our materials, instead of fully referenced materials.(very similar to our SeededTrackedEvent, consider consolidating and converting these to Referenced models instead of ID's)  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(default=None, alias="schema")
    format: Optional[SeededTrackedFormatEvent] = None
    asset: Optional[SeededTrackedAssetEvent] = None
    interaction: Optional[SeededTrackedInteractionEvent] = None
    keyboard: Optional[SeededTrackedKeyboardEvent] = None
    session: Optional[SeededTrackedSessionEvent] = None
    assets: Optional[SeededTrackedAssetsEvent] = None
    ml: Optional[SeededTrackedMachineLearningEvent] = None
    adoption: Optional[SeededTrackedAdoptionEvent] = None
    conversation: Optional[SeededTrackedConversationEvent] = None
    __properties = ["schema", "format", "asset", "interaction", "keyboard", "session", "assets", "ml", "adoption", "conversation"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SeededConnectorTracking:
        """Create an instance of SeededConnectorTracking from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of format
        if self.format:
            _dict['format'] = self.format.to_dict()
        # override the default output from pydantic by calling `to_dict()` of asset
        if self.asset:
            _dict['asset'] = self.asset.to_dict()
        # override the default output from pydantic by calling `to_dict()` of interaction
        if self.interaction:
            _dict['interaction'] = self.interaction.to_dict()
        # override the default output from pydantic by calling `to_dict()` of keyboard
        if self.keyboard:
            _dict['keyboard'] = self.keyboard.to_dict()
        # override the default output from pydantic by calling `to_dict()` of session
        if self.session:
            _dict['session'] = self.session.to_dict()
        # override the default output from pydantic by calling `to_dict()` of assets
        if self.assets:
            _dict['assets'] = self.assets.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ml
        if self.ml:
            _dict['ml'] = self.ml.to_dict()
        # override the default output from pydantic by calling `to_dict()` of adoption
        if self.adoption:
            _dict['adoption'] = self.adoption.to_dict()
        # override the default output from pydantic by calling `to_dict()` of conversation
        if self.conversation:
            _dict['conversation'] = self.conversation.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SeededConnectorTracking:
        """Create an instance of SeededConnectorTracking from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SeededConnectorTracking.parse_obj(obj)

        _obj = SeededConnectorTracking.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "format": SeededTrackedFormatEvent.from_dict(obj.get("format")) if obj.get("format") is not None else None,
            "asset": SeededTrackedAssetEvent.from_dict(obj.get("asset")) if obj.get("asset") is not None else None,
            "interaction": SeededTrackedInteractionEvent.from_dict(obj.get("interaction")) if obj.get("interaction") is not None else None,
            "keyboard": SeededTrackedKeyboardEvent.from_dict(obj.get("keyboard")) if obj.get("keyboard") is not None else None,
            "session": SeededTrackedSessionEvent.from_dict(obj.get("session")) if obj.get("session") is not None else None,
            "assets": SeededTrackedAssetsEvent.from_dict(obj.get("assets")) if obj.get("assets") is not None else None,
            "ml": SeededTrackedMachineLearningEvent.from_dict(obj.get("ml")) if obj.get("ml") is not None else None,
            "adoption": SeededTrackedAdoptionEvent.from_dict(obj.get("adoption")) if obj.get("adoption") is not None else None,
            "conversation": SeededTrackedConversationEvent.from_dict(obj.get("conversation")) if obj.get("conversation") is not None else None
        })
        return _obj

from pieces_os_client.models.seeded_tracked_asset_event import SeededTrackedAssetEvent
from pieces_os_client.models.seeded_tracked_assets_event import SeededTrackedAssetsEvent
from pieces_os_client.models.seeded_tracked_conversation_event import SeededTrackedConversationEvent
from pieces_os_client.models.seeded_tracked_format_event import SeededTrackedFormatEvent
SeededConnectorTracking.update_forward_refs()




# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError

from typing_extensions import Annotated
from pydantic import Field, StrictStr

from typing import Optional

from pieces_os_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_os_client.models.pkce import PKCE
from pieces_os_client.models.seeded_pkce import SeededPKCE
from pieces_os_client.models.tokenized_pkce import TokenizedPKCE

from pieces_os_client.api_client import ApiClient
from pieces_os_client.api_response import ApiResponse
from pieces_os_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PKCEApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def clear_pkce(self, **kwargs) -> None:  # noqa: E501
        """/pkce/clear [POST]  # noqa: E501

        This is a function to Clear a PKCE Authentication Flow  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.clear_pkce(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the clear_pkce_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.clear_pkce_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def clear_pkce_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """/pkce/clear [POST]  # noqa: E501

        This is a function to Clear a PKCE Authentication Flow  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.clear_pkce_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method clear_pkce" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # authentication setting
        _auth_settings = ['application']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/pkce/clear', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def generate_code(self, seeded_pkce : Annotated[Optional[SeededPKCE], Field(description="All of the properties that the client might want to send over to authorize a PKCE Code Flow")] = None, **kwargs) -> PKCE:  # noqa: E501
        """/pkce/code [POST]  # noqa: E501

        An endpoint to get the PKCE Code - this endpoint proxies the call out to Authorize within Auth0  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_code(seeded_pkce, async_req=True)
        >>> result = thread.get()

        :param seeded_pkce: All of the properties that the client might want to send over to authorize a PKCE Code Flow
        :type seeded_pkce: SeededPKCE
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PKCE
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the generate_code_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.generate_code_with_http_info(seeded_pkce, **kwargs)  # noqa: E501

    @validate_arguments
    def generate_code_with_http_info(self, seeded_pkce : Annotated[Optional[SeededPKCE], Field(description="All of the properties that the client might want to send over to authorize a PKCE Code Flow")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """/pkce/code [POST]  # noqa: E501

        An endpoint to get the PKCE Code - this endpoint proxies the call out to Authorize within Auth0  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_code_with_http_info(seeded_pkce, async_req=True)
        >>> result = thread.get()

        :param seeded_pkce: All of the properties that the client might want to send over to authorize a PKCE Code Flow
        :type seeded_pkce: SeededPKCE
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PKCE, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'seeded_pkce'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_code" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['seeded_pkce'] is not None:
            _body_params = _params['seeded_pkce']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['application']  # noqa: E501

        _response_types_map = {
            '200': "PKCE",
        }

        return self.api_client.call_api(
            '/pkce/code', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def generate_token(self, tokenized_pkce : Annotated[Optional[TokenizedPKCE], Field(description="The needed properties to exchange a PKCE Code for an OAuth Token")] = None, **kwargs) -> PKCE:  # noqa: E501
        """/pkce/token [POST]  # noqa: E501

        A proxy endpoint for PKCE token generation, internally calls Auth0 /oauth/token  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_token(tokenized_pkce, async_req=True)
        >>> result = thread.get()

        :param tokenized_pkce: The needed properties to exchange a PKCE Code for an OAuth Token
        :type tokenized_pkce: TokenizedPKCE
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PKCE
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the generate_token_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.generate_token_with_http_info(tokenized_pkce, **kwargs)  # noqa: E501

    @validate_arguments
    def generate_token_with_http_info(self, tokenized_pkce : Annotated[Optional[TokenizedPKCE], Field(description="The needed properties to exchange a PKCE Code for an OAuth Token")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """/pkce/token [POST]  # noqa: E501

        A proxy endpoint for PKCE token generation, internally calls Auth0 /oauth/token  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_token_with_http_info(tokenized_pkce, async_req=True)
        >>> result = thread.get()

        :param tokenized_pkce: The needed properties to exchange a PKCE Code for an OAuth Token
        :type tokenized_pkce: TokenizedPKCE
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PKCE, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'tokenized_pkce'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['tokenized_pkce'] is not None:
            _body_params = _params['tokenized_pkce']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['application']  # noqa: E501

        _response_types_map = {
            '200': "PKCE",
        }

        return self.api_client.call_api(
            '/pkce/token', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_challenge(self, **kwargs) -> PKCE:  # noqa: E501
        """Your GET endpoint  # noqa: E501

        An endpoint that returns a PKCE Challenge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_challenge(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PKCE
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_challenge_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_challenge_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def get_challenge_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """Your GET endpoint  # noqa: E501

        An endpoint that returns a PKCE Challenge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_challenge_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PKCE, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_challenge" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['application']  # noqa: E501

        _response_types_map = {
            '200': "PKCE",
        }

        return self.api_client.call_api(
            '/pkce/challenge', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def respond_with_code(self, code : Annotated[StrictStr, Field(..., description="The PKCE Code to be used to access a Token.")], state : Annotated[StrictStr, Field(..., description="Likely the state that will be returned which should match the requested state as well as the nonce")], var_schema : Optional[EmbeddedModelSchema] = None, **kwargs) -> PKCE:  # noqa: E501
        """/pkce/response/code [POST]  # noqa: E501

        This is a callback function hosted to help pass along the ResultedPKCE code from authorize through to the callback.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.respond_with_code(code, state, var_schema, async_req=True)
        >>> result = thread.get()

        :param code: The PKCE Code to be used to access a Token. (required)
        :type code: str
        :param state: Likely the state that will be returned which should match the requested state as well as the nonce (required)
        :type state: str
        :param var_schema:
        :type var_schema: EmbeddedModelSchema
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PKCE
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the respond_with_code_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.respond_with_code_with_http_info(code, state, var_schema, **kwargs)  # noqa: E501

    @validate_arguments
    def respond_with_code_with_http_info(self, code : Annotated[StrictStr, Field(..., description="The PKCE Code to be used to access a Token.")], state : Annotated[StrictStr, Field(..., description="Likely the state that will be returned which should match the requested state as well as the nonce")], var_schema : Optional[EmbeddedModelSchema] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """/pkce/response/code [POST]  # noqa: E501

        This is a callback function hosted to help pass along the ResultedPKCE code from authorize through to the callback.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.respond_with_code_with_http_info(code, state, var_schema, async_req=True)
        >>> result = thread.get()

        :param code: The PKCE Code to be used to access a Token. (required)
        :type code: str
        :param state: Likely the state that will be returned which should match the requested state as well as the nonce (required)
        :type state: str
        :param var_schema:
        :type var_schema: EmbeddedModelSchema
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PKCE, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'code',
            'state',
            'var_schema'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method respond_with_code" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        if _params['var_schema'] is not None:
            _form_params.append(('schema', _params['var_schema']))

        if _params['code'] is not None:
            _form_params.append(('code', _params['code']))

        if _params['state'] is not None:
            _form_params.append(('state', _params['state']))

        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/html'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/x-www-form-urlencoded']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['application']  # noqa: E501

        _response_types_map = {
            '200': "PKCE",
        }

        return self.api_client.call_api(
            '/pkce/response/code', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



from .base_websocket import BaseWebsocket

class HealthWS(BaseWebsocket):
	@property
	def url(self):
		return self.pieces_client.HEALTH_WS_URL

	def on_message(self, ws, message:str):
		self.on_message_callback(message)
		if message.lower().startswith("ok"):
			self.pieces_client.is_pos_stream_running = True
	
	def on_close(self, ws, close_status_code, close_msg):
		self.pieces_client.is_pos_stream_running = False
		self.pieces_client.port = None # Reset the port
		super().on_close(ws, close_status_code, close_msg)



# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field
from pieces_os_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_os_client.models.seeded_score import SeededScore

class SeededScoreIncrement(BaseModel):
    """
    This is the body for a respective scores increment,  This will enable us to know what material we want to increment, all of which are optional, if it is defined we will attempt to increment the material.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(default=None, alias="schema")
    asset: Optional[SeededScore] = None
    assets: Optional[SeededScore] = None
    website: Optional[SeededScore] = None
    websites: Optional[SeededScore] = None
    anchor: Optional[SeededScore] = None
    anchors: Optional[SeededScore] = None
    anchor_point: Optional[SeededScore] = Field(default=None, alias="anchorPoint")
    anchor_points: Optional[SeededScore] = Field(default=None, alias="anchorPoints")
    annotation: Optional[SeededScore] = None
    annotations: Optional[SeededScore] = None
    conversation: Optional[SeededScore] = None
    conversations: Optional[SeededScore] = None
    conversation_message: Optional[SeededScore] = Field(default=None, alias="conversationMessage")
    conversation_messages: Optional[SeededScore] = Field(default=None, alias="conversationMessages")
    share: Optional[SeededScore] = None
    shares: Optional[SeededScore] = None
    sensitive: Optional[SeededScore] = None
    sensitives: Optional[SeededScore] = None
    hint: Optional[SeededScore] = None
    hints: Optional[SeededScore] = None
    person: Optional[SeededScore] = None
    persons: Optional[SeededScore] = None
    tag: Optional[SeededScore] = None
    tags: Optional[SeededScore] = None
    workstream_summary: Optional[SeededScore] = None
    workstream_summaries: Optional[SeededScore] = None
    workstream_events: Optional[SeededScore] = None
    workstream_event: Optional[SeededScore] = None
    ranges: Optional[SeededScore] = None
    range: Optional[SeededScore] = None
    workstream_pattern_engine_sources: Optional[SeededScore] = None
    workstream_pattern_engine_source: Optional[SeededScore] = None
    models: Optional[SeededScore] = None
    model: Optional[SeededScore] = None
    __properties = ["schema", "asset", "assets", "website", "websites", "anchor", "anchors", "anchorPoint", "anchorPoints", "annotation", "annotations", "conversation", "conversations", "conversationMessage", "conversationMessages", "share", "shares", "sensitive", "sensitives", "hint", "hints", "person", "persons", "tag", "tags", "workstream_summary", "workstream_summaries", "workstream_events", "workstream_event", "ranges", "range", "workstream_pattern_engine_sources", "workstream_pattern_engine_source", "models", "model"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SeededScoreIncrement:
        """Create an instance of SeededScoreIncrement from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of asset
        if self.asset:
            _dict['asset'] = self.asset.to_dict()
        # override the default output from pydantic by calling `to_dict()` of assets
        if self.assets:
            _dict['assets'] = self.assets.to_dict()
        # override the default output from pydantic by calling `to_dict()` of website
        if self.website:
            _dict['website'] = self.website.to_dict()
        # override the default output from pydantic by calling `to_dict()` of websites
        if self.websites:
            _dict['websites'] = self.websites.to_dict()
        # override the default output from pydantic by calling `to_dict()` of anchor
        if self.anchor:
            _dict['anchor'] = self.anchor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of anchors
        if self.anchors:
            _dict['anchors'] = self.anchors.to_dict()
        # override the default output from pydantic by calling `to_dict()` of anchor_point
        if self.anchor_point:
            _dict['anchorPoint'] = self.anchor_point.to_dict()
        # override the default output from pydantic by calling `to_dict()` of anchor_points
        if self.anchor_points:
            _dict['anchorPoints'] = self.anchor_points.to_dict()
        # override the default output from pydantic by calling `to_dict()` of annotation
        if self.annotation:
            _dict['annotation'] = self.annotation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of annotations
        if self.annotations:
            _dict['annotations'] = self.annotations.to_dict()
        # override the default output from pydantic by calling `to_dict()` of conversation
        if self.conversation:
            _dict['conversation'] = self.conversation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of conversations
        if self.conversations:
            _dict['conversations'] = self.conversations.to_dict()
        # override the default output from pydantic by calling `to_dict()` of conversation_message
        if self.conversation_message:
            _dict['conversationMessage'] = self.conversation_message.to_dict()
        # override the default output from pydantic by calling `to_dict()` of conversation_messages
        if self.conversation_messages:
            _dict['conversationMessages'] = self.conversation_messages.to_dict()
        # override the default output from pydantic by calling `to_dict()` of share
        if self.share:
            _dict['share'] = self.share.to_dict()
        # override the default output from pydantic by calling `to_dict()` of shares
        if self.shares:
            _dict['shares'] = self.shares.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sensitive
        if self.sensitive:
            _dict['sensitive'] = self.sensitive.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sensitives
        if self.sensitives:
            _dict['sensitives'] = self.sensitives.to_dict()
        # override the default output from pydantic by calling `to_dict()` of hint
        if self.hint:
            _dict['hint'] = self.hint.to_dict()
        # override the default output from pydantic by calling `to_dict()` of hints
        if self.hints:
            _dict['hints'] = self.hints.to_dict()
        # override the default output from pydantic by calling `to_dict()` of person
        if self.person:
            _dict['person'] = self.person.to_dict()
        # override the default output from pydantic by calling `to_dict()` of persons
        if self.persons:
            _dict['persons'] = self.persons.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tag
        if self.tag:
            _dict['tag'] = self.tag.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tags
        if self.tags:
            _dict['tags'] = self.tags.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workstream_summary
        if self.workstream_summary:
            _dict['workstream_summary'] = self.workstream_summary.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workstream_summaries
        if self.workstream_summaries:
            _dict['workstream_summaries'] = self.workstream_summaries.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workstream_events
        if self.workstream_events:
            _dict['workstream_events'] = self.workstream_events.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workstream_event
        if self.workstream_event:
            _dict['workstream_event'] = self.workstream_event.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ranges
        if self.ranges:
            _dict['ranges'] = self.ranges.to_dict()
        # override the default output from pydantic by calling `to_dict()` of range
        if self.range:
            _dict['range'] = self.range.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workstream_pattern_engine_sources
        if self.workstream_pattern_engine_sources:
            _dict['workstream_pattern_engine_sources'] = self.workstream_pattern_engine_sources.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workstream_pattern_engine_source
        if self.workstream_pattern_engine_source:
            _dict['workstream_pattern_engine_source'] = self.workstream_pattern_engine_source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of models
        if self.models:
            _dict['models'] = self.models.to_dict()
        # override the default output from pydantic by calling `to_dict()` of model
        if self.model:
            _dict['model'] = self.model.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SeededScoreIncrement:
        """Create an instance of SeededScoreIncrement from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SeededScoreIncrement.parse_obj(obj)

        _obj = SeededScoreIncrement.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "asset": SeededScore.from_dict(obj.get("asset")) if obj.get("asset") is not None else None,
            "assets": SeededScore.from_dict(obj.get("assets")) if obj.get("assets") is not None else None,
            "website": SeededScore.from_dict(obj.get("website")) if obj.get("website") is not None else None,
            "websites": SeededScore.from_dict(obj.get("websites")) if obj.get("websites") is not None else None,
            "anchor": SeededScore.from_dict(obj.get("anchor")) if obj.get("anchor") is not None else None,
            "anchors": SeededScore.from_dict(obj.get("anchors")) if obj.get("anchors") is not None else None,
            "anchor_point": SeededScore.from_dict(obj.get("anchorPoint")) if obj.get("anchorPoint") is not None else None,
            "anchor_points": SeededScore.from_dict(obj.get("anchorPoints")) if obj.get("anchorPoints") is not None else None,
            "annotation": SeededScore.from_dict(obj.get("annotation")) if obj.get("annotation") is not None else None,
            "annotations": SeededScore.from_dict(obj.get("annotations")) if obj.get("annotations") is not None else None,
            "conversation": SeededScore.from_dict(obj.get("conversation")) if obj.get("conversation") is not None else None,
            "conversations": SeededScore.from_dict(obj.get("conversations")) if obj.get("conversations") is not None else None,
            "conversation_message": SeededScore.from_dict(obj.get("conversationMessage")) if obj.get("conversationMessage") is not None else None,
            "conversation_messages": SeededScore.from_dict(obj.get("conversationMessages")) if obj.get("conversationMessages") is not None else None,
            "share": SeededScore.from_dict(obj.get("share")) if obj.get("share") is not None else None,
            "shares": SeededScore.from_dict(obj.get("shares")) if obj.get("shares") is not None else None,
            "sensitive": SeededScore.from_dict(obj.get("sensitive")) if obj.get("sensitive") is not None else None,
            "sensitives": SeededScore.from_dict(obj.get("sensitives")) if obj.get("sensitives") is not None else None,
            "hint": SeededScore.from_dict(obj.get("hint")) if obj.get("hint") is not None else None,
            "hints": SeededScore.from_dict(obj.get("hints")) if obj.get("hints") is not None else None,
            "person": SeededScore.from_dict(obj.get("person")) if obj.get("person") is not None else None,
            "persons": SeededScore.from_dict(obj.get("persons")) if obj.get("persons") is not None else None,
            "tag": SeededScore.from_dict(obj.get("tag")) if obj.get("tag") is not None else None,
            "tags": SeededScore.from_dict(obj.get("tags")) if obj.get("tags") is not None else None,
            "workstream_summary": SeededScore.from_dict(obj.get("workstream_summary")) if obj.get("workstream_summary") is not None else None,
            "workstream_summaries": SeededScore.from_dict(obj.get("workstream_summaries")) if obj.get("workstream_summaries") is not None else None,
            "workstream_events": SeededScore.from_dict(obj.get("workstream_events")) if obj.get("workstream_events") is not None else None,
            "workstream_event": SeededScore.from_dict(obj.get("workstream_event")) if obj.get("workstream_event") is not None else None,
            "ranges": SeededScore.from_dict(obj.get("ranges")) if obj.get("ranges") is not None else None,
            "range": SeededScore.from_dict(obj.get("range")) if obj.get("range") is not None else None,
            "workstream_pattern_engine_sources": SeededScore.from_dict(obj.get("workstream_pattern_engine_sources")) if obj.get("workstream_pattern_engine_sources") is not None else None,
            "workstream_pattern_engine_source": SeededScore.from_dict(obj.get("workstream_pattern_engine_source")) if obj.get("workstream_pattern_engine_source") is not None else None,
            "models": SeededScore.from_dict(obj.get("models")) if obj.get("models") is not None else None,
            "model": SeededScore.from_dict(obj.get("model")) if obj.get("model") is not None else None
        })
        return _obj





from .ask_ws import AskStreamWS
from .assets_identifiers_ws import AssetsIdentifiersWS
from .auth_ws import AuthWS
from .health_ws import HealthWS
from .conversations_ws import ConversationWS
from .base_websocket import BaseWebsocket

__all__ = [
	"AskStreamWS",
	"AssetsIdentifiersWS",
	"AuthWS",
	"HealthWS",
	"ConversationWS",
	"BaseWebsocket"
]


# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from pieces_os_client.models.embedded_model_schema import EmbeddedModelSchema

class RevokedPKCE(BaseModel):
    """
    A model to support revoking a Token Generated Through PKCE  The behaviour of this endpoint depends on the state of the Refresh Token Revocation Deletes Grant toggle.  If this toggle is enabled, then each revocation request invalidates not only the specific token, but all other tokens based on the same authorization grant.  This means that all Refresh Tokens that have been issued for the same user, application, and audience will be revoked. If this toggle is disabled, then only the refresh token is revoked, while the grant is left intact  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(default=None, alias="schema")
    client_id: StrictStr = Field(default=..., description="Your application's Client ID. The application should match the one the Refresh Token was issued for.")
    token: StrictStr = Field(default=..., description="The Refresh Token you want to revoke.")
    __properties = ["schema", "client_id", "token"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RevokedPKCE:
        """Create an instance of RevokedPKCE from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RevokedPKCE:
        """Create an instance of RevokedPKCE from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RevokedPKCE.parse_obj(obj)

        _obj = RevokedPKCE.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "client_id": obj.get("client_id"),
            "token": obj.get("token")
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError

from typing_extensions import Annotated
from pydantic import Field, StrictBool, StrictStr

from typing import Optional

from pieces_os_client.models.anchor_point import AnchorPoint
from pieces_os_client.models.seeded_score_increment import SeededScoreIncrement

from pieces_os_client.api_client import ApiClient
from pieces_os_client.api_response import ApiResponse
from pieces_os_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AnchorPointApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def anchor_point_scores_increment(self, anchor_point : Annotated[StrictStr, Field(..., description="This is the specific uuid of an anchor_point.")], seeded_score_increment : Optional[SeededScoreIncrement] = None, **kwargs) -> None:  # noqa: E501
        """'/anchor_point/{anchor_point}/scores/increment' [POST]  # noqa: E501

        This will take in a SeededScoreIncrement and will increment the material relative to the incoming body.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.anchor_point_scores_increment(anchor_point, seeded_score_increment, async_req=True)
        >>> result = thread.get()

        :param anchor_point: This is the specific uuid of an anchor_point. (required)
        :type anchor_point: str
        :param seeded_score_increment:
        :type seeded_score_increment: SeededScoreIncrement
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the anchor_point_scores_increment_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.anchor_point_scores_increment_with_http_info(anchor_point, seeded_score_increment, **kwargs)  # noqa: E501

    @validate_arguments
    def anchor_point_scores_increment_with_http_info(self, anchor_point : Annotated[StrictStr, Field(..., description="This is the specific uuid of an anchor_point.")], seeded_score_increment : Optional[SeededScoreIncrement] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """'/anchor_point/{anchor_point}/scores/increment' [POST]  # noqa: E501

        This will take in a SeededScoreIncrement and will increment the material relative to the incoming body.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.anchor_point_scores_increment_with_http_info(anchor_point, seeded_score_increment, async_req=True)
        >>> result = thread.get()

        :param anchor_point: This is the specific uuid of an anchor_point. (required)
        :type anchor_point: str
        :param seeded_score_increment:
        :type seeded_score_increment: SeededScoreIncrement
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'anchor_point',
            'seeded_score_increment'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method anchor_point_scores_increment" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['anchor_point'] is not None:
            _path_params['anchor_point'] = _params['anchor_point']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['seeded_score_increment'] is not None:
            _body_params = _params['seeded_score_increment']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['application']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/anchor_point/{anchor_point}/scores/increment', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def anchor_point_specific_anchor_point_snapshot(self, anchor_point : Annotated[StrictStr, Field(..., description="This is the specific uuid of an anchor_point.")], transferables : Annotated[Optional[StrictBool], Field(description="This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)")] = None, **kwargs) -> AnchorPoint:  # noqa: E501
        """/anchor_point/{anchor_point} [GET]  # noqa: E501

        This will get a snapshot of a single anchorPoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.anchor_point_specific_anchor_point_snapshot(anchor_point, transferables, async_req=True)
        >>> result = thread.get()

        :param anchor_point: This is the specific uuid of an anchor_point. (required)
        :type anchor_point: str
        :param transferables: This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)
        :type transferables: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnchorPoint
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the anchor_point_specific_anchor_point_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.anchor_point_specific_anchor_point_snapshot_with_http_info(anchor_point, transferables, **kwargs)  # noqa: E501

    @validate_arguments
    def anchor_point_specific_anchor_point_snapshot_with_http_info(self, anchor_point : Annotated[StrictStr, Field(..., description="This is the specific uuid of an anchor_point.")], transferables : Annotated[Optional[StrictBool], Field(description="This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """/anchor_point/{anchor_point} [GET]  # noqa: E501

        This will get a snapshot of a single anchorPoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.anchor_point_specific_anchor_point_snapshot_with_http_info(anchor_point, transferables, async_req=True)
        >>> result = thread.get()

        :param anchor_point: This is the specific uuid of an anchor_point. (required)
        :type anchor_point: str
        :param transferables: This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)
        :type transferables: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AnchorPoint, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'anchor_point',
            'transferables'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method anchor_point_specific_anchor_point_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['anchor_point'] is not None:
            _path_params['anchor_point'] = _params['anchor_point']


        # process the query parameters
        _query_params = []
        if _params.get('transferables') is not None:  # noqa: E501
            _query_params.append(('transferables', _params['transferables']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # authentication setting
        _auth_settings = ['application']  # noqa: E501

        _response_types_map = {
            '200': "AnchorPoint",
            '410': "str",
        }

        return self.api_client.call_api(
            '/anchor_point/{anchor_point}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def anchor_point_update(self, transferables : Annotated[Optional[StrictBool], Field(description="This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)")] = None, anchor_point : Optional[AnchorPoint] = None, **kwargs) -> AnchorPoint:  # noqa: E501
        """/anchor_point/update [POST]  # noqa: E501

        This will update a specific anchorPoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.anchor_point_update(transferables, anchor_point, async_req=True)
        >>> result = thread.get()

        :param transferables: This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)
        :type transferables: bool
        :param anchor_point:
        :type anchor_point: AnchorPoint
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AnchorPoint
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the anchor_point_update_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.anchor_point_update_with_http_info(transferables, anchor_point, **kwargs)  # noqa: E501

    @validate_arguments
    def anchor_point_update_with_http_info(self, transferables : Annotated[Optional[StrictBool], Field(description="This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)")] = None, anchor_point : Optional[AnchorPoint] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """/anchor_point/update [POST]  # noqa: E501

        This will update a specific anchorPoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.anchor_point_update_with_http_info(transferables, anchor_point, async_req=True)
        >>> result = thread.get()

        :param transferables: This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)
        :type transferables: bool
        :param anchor_point:
        :type anchor_point: AnchorPoint
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AnchorPoint, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'transferables',
            'anchor_point'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method anchor_point_update" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('transferables') is not None:  # noqa: E501
            _query_params.append(('transferables', _params['transferables']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['anchor_point'] is not None:
            _body_params = _params['anchor_point']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['application']  # noqa: E501

        _response_types_map = {
            '200': "AnchorPoint",
            '500': "str",
        }

        return self.api_client.call_api(
            '/anchor_point/update', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from pieces_os_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_os_client.models.referenced_anchor import ReferencedAnchor
from pieces_os_client.models.referenced_asset import ReferencedAsset
from pieces_os_client.models.seed import Seed
from pieces_os_client.models.text_location import TextLocation

class RelevantQGPTSeed(BaseModel):
    """
    This is a generic model used, to wrap a seed, as well as give an identifier used to further identifiy this snippet.  Seed is optional here because you may just want to provide the id, and not the original seed.  id is also optional here as you may provide an id or not here.(however with specific endpoint this ID is a guarentee.)  location:(optional) if a path or an anchor is passed in, this will let us know the specific location within the 'file' that this relevant seed is located           note: if this is null and a path/anchor is present then we will use the entire file that is provided.(this logic will be determined within the relevance flow & not by the user)  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(default=None, alias="schema")
    id: Optional[StrictStr] = None
    seed: Optional[Seed] = None
    path: Optional[StrictStr] = Field(default=None, description="This is an optional file path")
    anchor: Optional[ReferencedAnchor] = None
    asset: Optional[ReferencedAsset] = None
    location: Optional[TextLocation] = None
    __properties = ["schema", "id", "seed", "path", "anchor", "asset", "location"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RelevantQGPTSeed:
        """Create an instance of RelevantQGPTSeed from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of seed
        if self.seed:
            _dict['seed'] = self.seed.to_dict()
        # override the default output from pydantic by calling `to_dict()` of anchor
        if self.anchor:
            _dict['anchor'] = self.anchor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of asset
        if self.asset:
            _dict['asset'] = self.asset.to_dict()
        # override the default output from pydantic by calling `to_dict()` of location
        if self.location:
            _dict['location'] = self.location.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RelevantQGPTSeed:
        """Create an instance of RelevantQGPTSeed from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RelevantQGPTSeed.parse_obj(obj)

        _obj = RelevantQGPTSeed.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "id": obj.get("id"),
            "seed": Seed.from_dict(obj.get("seed")) if obj.get("seed") is not None else None,
            "path": obj.get("path"),
            "anchor": ReferencedAnchor.from_dict(obj.get("anchor")) if obj.get("anchor") is not None else None,
            "asset": ReferencedAsset.from_dict(obj.get("asset")) if obj.get("asset") is not None else None,
            "location": TextLocation.from_dict(obj.get("location")) if obj.get("location") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr
from pieces_os_client.models.application_name_enum import ApplicationNameEnum
from pieces_os_client.models.capabilities_enum import CapabilitiesEnum
from pieces_os_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_os_client.models.mechanism_enum import MechanismEnum
from pieces_os_client.models.platform_enum import PlatformEnum
from pieces_os_client.models.privacy_enum import PrivacyEnum
from pieces_os_client.models.seeded_asset_enrichment import SeededAssetEnrichment

class Application(BaseModel):
    """
    A Model to describe what application a format/analytics event originated.  mechanism: This will let us know where this came from. ie.only 2 enums are used here or else throw and error. default mechanism here is MANUAL- meaning that this came from our user Connecting an application. INTERNAL - means that this came from a shareable link  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(default=None, alias="schema")
    id: StrictStr = Field(default=..., description="The ID of the application at the device level")
    name: ApplicationNameEnum = Field(...)
    version: StrictStr = Field(default=..., description="This is the specific version number 0.0.0")
    platform: PlatformEnum = Field(...)
    onboarded: StrictBool = Field(...)
    privacy: PrivacyEnum = Field(...)
    capabilities: Optional[CapabilitiesEnum] = None
    mechanism: Optional[MechanismEnum] = None
    automatic_unload: Optional[StrictBool] = Field(default=None, alias="automaticUnload", description="This is a proper that will let us know if we will proactivity unload all of your machine learning models.by default this is false.")
    enrichment: Optional[SeededAssetEnrichment] = None
    __properties = ["schema", "id", "name", "version", "platform", "onboarded", "privacy", "capabilities", "mechanism", "automaticUnload", "enrichment"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Application:
        """Create an instance of Application from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of enrichment
        if self.enrichment:
            _dict['enrichment'] = self.enrichment.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Application:
        """Create an instance of Application from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Application.parse_obj(obj)

        _obj = Application.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "id": obj.get("id"),
            "name": obj.get("name"),
            "version": obj.get("version"),
            "platform": obj.get("platform"),
            "onboarded": obj.get("onboarded"),
            "privacy": obj.get("privacy"),
            "capabilities": obj.get("capabilities"),
            "mechanism": obj.get("mechanism"),
            "automatic_unload": obj.get("automaticUnload"),
            "enrichment": SeededAssetEnrichment.from_dict(obj.get("enrichment")) if obj.get("enrichment") is not None else None
        })
        return _obj





from .asset import BasicAsset
from .chat import BasicChat
from .message import BasicMessage
from .user import BasicUser
from .tag import BasicTag
from .annotation import BasicAnnotation
from .website import BasicWebsite

__all__ = [
	"BasicAsset",
	"BasicChat",
	"BasicMessage",
	"BasicUser",
	"BasicTag",
	"BasicAnnotation",
	"BasicWebsite"
]



# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conlist
from pieces_os_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_os_client.models.exported_database_formats import ExportedDatabaseFormats

class ExportedDatabase(BaseModel):
    """
    ExportedDatabase
    """
    analyses: conlist(StrictInt) = Field(...)
    applications: conlist(StrictInt) = Field(...)
    assets: conlist(StrictInt) = Field(...)
    code_analyses: conlist(StrictInt) = Field(default=..., alias="codeAnalyses")
    files: conlist(StrictInt) = Field(...)
    format_metrics: conlist(StrictInt) = Field(default=..., alias="formatMetrics")
    formats: conlist(StrictInt) = Field(...)
    fragments: conlist(StrictInt) = Field(...)
    image_analyses: conlist(StrictInt) = Field(default=..., alias="imageAnalyses")
    models: conlist(StrictInt) = Field(...)
    ocr_analyses: conlist(StrictInt) = Field(default=..., alias="ocrAnalyses")
    persons: conlist(StrictInt) = Field(...)
    sensitives: conlist(StrictInt) = Field(...)
    tags: conlist(StrictInt) = Field(...)
    websites: conlist(StrictInt) = Field(...)
    values: ExportedDatabaseFormats = Field(...)
    version: StrictStr = Field(default=..., description="This is the version of your os_server or cloud_server that we we exporting from.")
    var_schema: Optional[EmbeddedModelSchema] = Field(default=None, alias="schema")
    relationships: Optional[conlist(StrictInt)] = None
    activities: Optional[conlist(StrictInt)] = None
    annotations: Optional[conlist(StrictInt)] = None
    hints: Optional[conlist(StrictInt)] = None
    anchors: Optional[conlist(StrictInt)] = None
    anchor_points: Optional[conlist(StrictInt)] = Field(default=None, alias="anchorPoints")
    conversations: Optional[conlist(StrictInt)] = None
    conversation_messages: Optional[conlist(StrictInt)] = Field(default=None, alias="conversationMessages")
    workstream_events: Optional[conlist(StrictInt)] = Field(default=None, alias="workstreamEvents")
    ranges: Optional[conlist(StrictInt)] = None
    workstream_summaries: Optional[conlist(StrictInt)] = Field(default=None, alias="workstreamSummaries")
    workstream_pattern_engine_sources: Optional[conlist(StrictInt)] = Field(default=None, alias="workstreamPatternEngineSources")
    message_values: Optional[ExportedDatabaseFormats] = Field(default=None, alias="messageValues")
    workstream_event_values: Optional[ExportedDatabaseFormats] = Field(default=None, alias="workstreamEventValues")
    __properties = ["analyses", "applications", "assets", "codeAnalyses", "files", "formatMetrics", "formats", "fragments", "imageAnalyses", "models", "ocrAnalyses", "persons", "sensitives", "tags", "websites", "values", "version", "schema", "relationships", "activities", "annotations", "hints", "anchors", "anchorPoints", "conversations", "conversationMessages", "workstreamEvents", "ranges", "workstreamSummaries", "workstreamPatternEngineSources", "messageValues", "workstreamEventValues"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ExportedDatabase:
        """Create an instance of ExportedDatabase from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of values
        if self.values:
            _dict['values'] = self.values.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of message_values
        if self.message_values:
            _dict['messageValues'] = self.message_values.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workstream_event_values
        if self.workstream_event_values:
            _dict['workstreamEventValues'] = self.workstream_event_values.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ExportedDatabase:
        """Create an instance of ExportedDatabase from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ExportedDatabase.parse_obj(obj)

        _obj = ExportedDatabase.parse_obj({
            "analyses": obj.get("analyses"),
            "applications": obj.get("applications"),
            "assets": obj.get("assets"),
            "code_analyses": obj.get("codeAnalyses"),
            "files": obj.get("files"),
            "format_metrics": obj.get("formatMetrics"),
            "formats": obj.get("formats"),
            "fragments": obj.get("fragments"),
            "image_analyses": obj.get("imageAnalyses"),
            "models": obj.get("models"),
            "ocr_analyses": obj.get("ocrAnalyses"),
            "persons": obj.get("persons"),
            "sensitives": obj.get("sensitives"),
            "tags": obj.get("tags"),
            "websites": obj.get("websites"),
            "values": ExportedDatabaseFormats.from_dict(obj.get("values")) if obj.get("values") is not None else None,
            "version": obj.get("version"),
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "relationships": obj.get("relationships"),
            "activities": obj.get("activities"),
            "annotations": obj.get("annotations"),
            "hints": obj.get("hints"),
            "anchors": obj.get("anchors"),
            "anchor_points": obj.get("anchorPoints"),
            "conversations": obj.get("conversations"),
            "conversation_messages": obj.get("conversationMessages"),
            "workstream_events": obj.get("workstreamEvents"),
            "ranges": obj.get("ranges"),
            "workstream_summaries": obj.get("workstreamSummaries"),
            "workstream_pattern_engine_sources": obj.get("workstreamPatternEngineSources"),
            "message_values": ExportedDatabaseFormats.from_dict(obj.get("messageValues")) if obj.get("messageValues") is not None else None,
            "workstream_event_values": ExportedDatabaseFormats.from_dict(obj.get("workstreamEventValues")) if obj.get("workstreamEventValues") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field
from pieces_os_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_os_client.models.flattened_anchors import FlattenedAnchors
from pieces_os_client.models.flattened_persons import FlattenedPersons
from pieces_os_client.models.flattened_websites import FlattenedWebsites
from pieces_os_client.models.seeds import Seeds
from pieces_os_client.models.text_location import TextLocation

class TextuallyExtractedMaterial(BaseModel):
    """
    This is an extraction, this was a person/website/anchor that was extracted  this will return the text location where this was found within the extraction.  as well return the material itself that was extracted.  Note: - seeds: will only be extracted people if provided, because the website/anchors will be created if extracted. - basically only thing that is different about the extracted people, if that if we extract a person that was not already saved,   then we will not save them, however if there are related people then we will add them as well.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(default=None, alias="schema")
    match: TextLocation = Field(...)
    websites: Optional[FlattenedWebsites] = None
    anchors: Optional[FlattenedAnchors] = None
    persons: Optional[FlattenedPersons] = None
    seeds: Optional[Seeds] = None
    __properties = ["schema", "match", "websites", "anchors", "persons", "seeds"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TextuallyExtractedMaterial:
        """Create an instance of TextuallyExtractedMaterial from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of match
        if self.match:
            _dict['match'] = self.match.to_dict()
        # override the default output from pydantic by calling `to_dict()` of websites
        if self.websites:
            _dict['websites'] = self.websites.to_dict()
        # override the default output from pydantic by calling `to_dict()` of anchors
        if self.anchors:
            _dict['anchors'] = self.anchors.to_dict()
        # override the default output from pydantic by calling `to_dict()` of persons
        if self.persons:
            _dict['persons'] = self.persons.to_dict()
        # override the default output from pydantic by calling `to_dict()` of seeds
        if self.seeds:
            _dict['seeds'] = self.seeds.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TextuallyExtractedMaterial:
        """Create an instance of TextuallyExtractedMaterial from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TextuallyExtractedMaterial.parse_obj(obj)

        _obj = TextuallyExtractedMaterial.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "match": TextLocation.from_dict(obj.get("match")) if obj.get("match") is not None else None,
            "websites": FlattenedWebsites.from_dict(obj.get("websites")) if obj.get("websites") is not None else None,
            "anchors": FlattenedAnchors.from_dict(obj.get("anchors")) if obj.get("anchors") is not None else None,
            "persons": FlattenedPersons.from_dict(obj.get("persons")) if obj.get("persons") is not None else None,
            "seeds": Seeds.from_dict(obj.get("seeds")) if obj.get("seeds") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr
from pieces_os_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_os_client.models.grouped_timestamp import GroupedTimestamp
from pieces_os_client.models.mechanism_enum import MechanismEnum
from pieces_os_client.models.person_access import PersonAccess
from pieces_os_client.models.person_type import PersonType
from pieces_os_client.models.score import Score

class FlattenedPerson(BaseModel):
    """
    if expiration is add then, after the alloted expiration date the user will only have view && comment only permissions. Only present in the case there is a scope such as a defined collection/asset...  if asset is passed then that means this person belongs to a scoped asset.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(default=None, alias="schema")
    id: StrictStr = Field(...)
    created: GroupedTimestamp = Field(...)
    updated: GroupedTimestamp = Field(...)
    deleted: Optional[GroupedTimestamp] = None
    type: PersonType = Field(...)
    assets: Optional[FlattenedAssets] = None
    mechanisms: Optional[Dict[str, MechanismEnum]] = Field(default=None, description="This is a Map<String, MechanismEnum> where the the key is an asset id.")
    interactions: Optional[StrictInt] = Field(default=None, description="This is an optional value that will keep track of the number of times this has been interacted with.")
    access: Optional[Dict[str, PersonAccess]] = Field(default=None, description="This is a Map<String, PersonAccess> where the the key is an asset id.")
    tags: Optional[FlattenedTags] = None
    websites: Optional[FlattenedWebsites] = None
    models: Optional[Dict[str, PersonModel]] = Field(default=None, description="This is a Map<String, PersonModel>, where the the key is an asset id.")
    annotations: Optional[FlattenedAnnotations] = None
    score: Optional[Score] = None
    summaries: Optional[FlattenedWorkstreamSummaries] = None
    anchors: Optional[FlattenedAnchors] = None
    messages: Optional[FlattenedConversationMessages] = None
    __properties = ["schema", "id", "created", "updated", "deleted", "type", "assets", "mechanisms", "interactions", "access", "tags", "websites", "models", "annotations", "score", "summaries", "anchors", "messages"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FlattenedPerson:
        """Create an instance of FlattenedPerson from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of created
        if self.created:
            _dict['created'] = self.created.to_dict()
        # override the default output from pydantic by calling `to_dict()` of updated
        if self.updated:
            _dict['updated'] = self.updated.to_dict()
        # override the default output from pydantic by calling `to_dict()` of deleted
        if self.deleted:
            _dict['deleted'] = self.deleted.to_dict()
        # override the default output from pydantic by calling `to_dict()` of type
        if self.type:
            _dict['type'] = self.type.to_dict()
        # override the default output from pydantic by calling `to_dict()` of assets
        if self.assets:
            _dict['assets'] = self.assets.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each value in access (dict)
        _field_dict = {}
        if self.access:
            for _key in self.access:
                if self.access[_key]:
                    _field_dict[_key] = self.access[_key].to_dict()
            _dict['access'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of tags
        if self.tags:
            _dict['tags'] = self.tags.to_dict()
        # override the default output from pydantic by calling `to_dict()` of websites
        if self.websites:
            _dict['websites'] = self.websites.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each value in models (dict)
        _field_dict = {}
        if self.models:
            for _key in self.models:
                if self.models[_key]:
                    _field_dict[_key] = self.models[_key].to_dict()
            _dict['models'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of annotations
        if self.annotations:
            _dict['annotations'] = self.annotations.to_dict()
        # override the default output from pydantic by calling `to_dict()` of score
        if self.score:
            _dict['score'] = self.score.to_dict()
        # override the default output from pydantic by calling `to_dict()` of summaries
        if self.summaries:
            _dict['summaries'] = self.summaries.to_dict()
        # override the default output from pydantic by calling `to_dict()` of anchors
        if self.anchors:
            _dict['anchors'] = self.anchors.to_dict()
        # override the default output from pydantic by calling `to_dict()` of messages
        if self.messages:
            _dict['messages'] = self.messages.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FlattenedPerson:
        """Create an instance of FlattenedPerson from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FlattenedPerson.parse_obj(obj)

        _obj = FlattenedPerson.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "id": obj.get("id"),
            "created": GroupedTimestamp.from_dict(obj.get("created")) if obj.get("created") is not None else None,
            "updated": GroupedTimestamp.from_dict(obj.get("updated")) if obj.get("updated") is not None else None,
            "deleted": GroupedTimestamp.from_dict(obj.get("deleted")) if obj.get("deleted") is not None else None,
            "type": PersonType.from_dict(obj.get("type")) if obj.get("type") is not None else None,
            "assets": FlattenedAssets.from_dict(obj.get("assets")) if obj.get("assets") is not None else None,
            "mechanisms": dict((_k, _v) for _k, _v in obj.get("mechanisms").items()),
            "interactions": obj.get("interactions"),
            "access": dict(
                (_k, PersonAccess.from_dict(_v))
                for _k, _v in obj.get("access").items()
            )
            if obj.get("access") is not None
            else None,
            "tags": FlattenedTags.from_dict(obj.get("tags")) if obj.get("tags") is not None else None,
            "websites": FlattenedWebsites.from_dict(obj.get("websites")) if obj.get("websites") is not None else None,
            "models": dict(
                (_k, PersonModel.from_dict(_v))
                for _k, _v in obj.get("models").items()
            )
            if obj.get("models") is not None
            else None,
            "annotations": FlattenedAnnotations.from_dict(obj.get("annotations")) if obj.get("annotations") is not None else None,
            "score": Score.from_dict(obj.get("score")) if obj.get("score") is not None else None,
            "summaries": FlattenedWorkstreamSummaries.from_dict(obj.get("summaries")) if obj.get("summaries") is not None else None,
            "anchors": FlattenedAnchors.from_dict(obj.get("anchors")) if obj.get("anchors") is not None else None,
            "messages": FlattenedConversationMessages.from_dict(obj.get("messages")) if obj.get("messages") is not None else None
        })
        return _obj

from pieces_os_client.models.flattened_anchors import FlattenedAnchors
from pieces_os_client.models.flattened_annotations import FlattenedAnnotations
from pieces_os_client.models.flattened_assets import FlattenedAssets
from pieces_os_client.models.flattened_conversation_messages import FlattenedConversationMessages
from pieces_os_client.models.flattened_tags import FlattenedTags
from pieces_os_client.models.flattened_websites import FlattenedWebsites
from pieces_os_client.models.flattened_workstream_summaries import FlattenedWorkstreamSummaries
from pieces_os_client.models.person_model import PersonModel
FlattenedPerson.update_forward_refs()




# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class SensitiveCategoryEnum(str, Enum):
    """
    This is the enum that is use to describe the category of our Sensitive Model.
    """

    """
    allowed enum values
    """
    SECRET = 'SECRET'
    API_KEY = 'API_KEY'
    CLIENT_ID = 'CLIENT_ID'
    CLIENT_SECRET = 'CLIENT_SECRET'
    SECRET_KEY = 'SECRET_KEY'
    API_TOKEN = 'API_TOKEN'
    ACCESS_KEY = 'ACCESS_KEY'
    ACCESS_TOKEN = 'ACCESS_TOKEN'
    URL = 'URL'
    PUBLIC_KEY = 'PUBLIC_KEY'
    PRIVATE_KEY = 'PRIVATE_KEY'
    API_ID = 'API_ID'
    WEB_HOOK_URL = 'WEB_HOOK_URL'

    @classmethod
    def from_json(cls, json_str: str) -> SensitiveCategoryEnum:
        """Create an instance of SensitiveCategoryEnum from a JSON string"""
        return SensitiveCategoryEnum(json.loads(json_str))





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, validator
from pieces_os_client.models.embedded_model_schema import EmbeddedModelSchema

class AnalyticsTrackedAdoptionEventIdentifierDescriptionPairs(BaseModel):
    """
    AnalyticsTrackedAdoptionEventIdentifierDescriptionPairs
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(default=None, alias="schema")
    adoption_install: Optional[StrictStr] = None
    adoption_uninstall: Optional[StrictStr] = None
    __properties = ["schema", "adoption_install", "adoption_uninstall"]

    @validator('adoption_install')
    def adoption_install_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('the_user_has_installed_a_pieces_application',):
            raise ValueError("must be one of enum values ('the_user_has_installed_a_pieces_application')")
        return value

    @validator('adoption_uninstall')
    def adoption_uninstall_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('the_user_has_uninstalled_a_pieces_application',):
            raise ValueError("must be one of enum values ('the_user_has_uninstalled_a_pieces_application')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AnalyticsTrackedAdoptionEventIdentifierDescriptionPairs:
        """Create an instance of AnalyticsTrackedAdoptionEventIdentifierDescriptionPairs from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AnalyticsTrackedAdoptionEventIdentifierDescriptionPairs:
        """Create an instance of AnalyticsTrackedAdoptionEventIdentifierDescriptionPairs from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AnalyticsTrackedAdoptionEventIdentifierDescriptionPairs.parse_obj(obj)

        _obj = AnalyticsTrackedAdoptionEventIdentifierDescriptionPairs.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "adoption_install": obj.get("adoption_install"),
            "adoption_uninstall": obj.get("adoption_uninstall")
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class OSDeviceRAMTypeEnum(str, Enum):
    """
    ddr3, ddr4, ddr5, gddr6 : this is the type of the RAM
    """

    """
    allowed enum values
    """
    DDR2 = 'DDR2'
    DDR3 = 'DDR3'
    DDR4 = 'DDR4'
    DDR5 = 'DDR5'
    GDDR6 = 'GDDR6'

    @classmethod
    def from_json(cls, json_str: str) -> OSDeviceRAMTypeEnum:
        """Create an instance of OSDeviceRAMTypeEnum from a JSON string"""
        return OSDeviceRAMTypeEnum(json.loads(json_str))





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, validator
from pieces_os_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_os_client.models.seeded_anchor import SeededAnchor
from pieces_os_client.models.seeded_asset import SeededAsset
from pieces_os_client.models.seeded_person import SeededPerson
from pieces_os_client.models.seeded_website import SeededWebsite

class Seed(BaseModel):
    """
    A seed Model used to wrap a format or asset  Note: we will expand this now to support additional paramerters.  Note: however if create an asset, only pass in the asset, not passing in an asset in this case will cause the endpoint to fail.  TODO: for a breaking change update the type enum here to add support for the additional materials or remove it entirely.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(default=None, alias="schema")
    asset: Optional[SeededAsset] = None
    person: Optional[SeededPerson] = None
    anchor: Optional[SeededAnchor] = None
    website: Optional[SeededWebsite] = None
    type: Optional[StrictStr] = None
    __properties = ["schema", "asset", "person", "anchor", "website", "type"]

    @validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('SEEDED_FORMAT', 'SEEDED_ASSET',):
            raise ValueError("must be one of enum values ('SEEDED_FORMAT', 'SEEDED_ASSET')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Seed:
        """Create an instance of Seed from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of asset
        if self.asset:
            _dict['asset'] = self.asset.to_dict()
        # override the default output from pydantic by calling `to_dict()` of person
        if self.person:
            _dict['person'] = self.person.to_dict()
        # override the default output from pydantic by calling `to_dict()` of anchor
        if self.anchor:
            _dict['anchor'] = self.anchor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of website
        if self.website:
            _dict['website'] = self.website.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Seed:
        """Create an instance of Seed from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Seed.parse_obj(obj)

        _obj = Seed.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "asset": SeededAsset.from_dict(obj.get("asset")) if obj.get("asset") is not None else None,
            "person": SeededPerson.from_dict(obj.get("person")) if obj.get("person") is not None else None,
            "anchor": SeededAnchor.from_dict(obj.get("anchor")) if obj.get("anchor") is not None else None,
            "website": SeededWebsite.from_dict(obj.get("website")) if obj.get("website") is not None else None,
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, validator
from pieces_os_client.models.embedded_model_schema import EmbeddedModelSchema

class TrackedFormatEventIdentifierDescriptionPairs(BaseModel):
    """
    This is a model that allows us to send send over super specific format related events such as copied, deleted, downloaded, etc  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(default=None, alias="schema")
    format_created: Optional[StrictStr] = Field(default=None, description="The key value pair for an asset being created.")
    format_copied: Optional[StrictStr] = Field(default=None, description="If a format was copied entirely")
    format_partially_copied: Optional[StrictStr] = Field(default=None, description="If a format was copied partially")
    format_downloaded: Optional[StrictStr] = Field(default=None, description="If a format was downloaded")
    format_deleted: Optional[StrictStr] = Field(default=None, description="If an format was deleted")
    format_generic_classification_updated: Optional[StrictStr] = Field(default=None, description="If a generic classification was changed on a format")
    format_specific_classification_updated: Optional[StrictStr] = Field(default=None, description="If a specific classification was changed on a format")
    format_updated: Optional[StrictStr] = Field(default=None, description="a format was updated, generic update.")
    format_inserted: Optional[StrictStr] = Field(default=None, description="a format was inserted")
    format_value_edited: Optional[StrictStr] = Field(default=None, description="a format's value was update ie, the text, etc...")
    __properties = ["schema", "format_created", "format_copied", "format_partially_copied", "format_downloaded", "format_deleted", "format_generic_classification_updated", "format_specific_classification_updated", "format_updated", "format_inserted", "format_value_edited"]

    @validator('format_created')
    def format_created_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_format_was_created',):
            raise ValueError("must be one of enum values ('a_format_was_created')")
        return value

    @validator('format_copied')
    def format_copied_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('if_a_format_was_entirely_copied',):
            raise ValueError("must be one of enum values ('if_a_format_was_entirely_copied')")
        return value

    @validator('format_partially_copied')
    def format_partially_copied_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('if_a_format_was_partially_copied',):
            raise ValueError("must be one of enum values ('if_a_format_was_partially_copied')")
        return value

    @validator('format_downloaded')
    def format_downloaded_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('if_a_format_was_downloaded',):
            raise ValueError("must be one of enum values ('if_a_format_was_downloaded')")
        return value

    @validator('format_deleted')
    def format_deleted_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('if_a_format_was_deleted',):
            raise ValueError("must be one of enum values ('if_a_format_was_deleted')")
        return value

    @validator('format_generic_classification_updated')
    def format_generic_classification_updated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('if_a_generic_classification_was_changed_on_a_format',):
            raise ValueError("must be one of enum values ('if_a_generic_classification_was_changed_on_a_format')")
        return value

    @validator('format_specific_classification_updated')
    def format_specific_classification_updated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('if_a_specific_classification_was_changed_on_a_format',):
            raise ValueError("must be one of enum values ('if_a_specific_classification_was_changed_on_a_format')")
        return value

    @validator('format_updated')
    def format_updated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_format_was_updated',):
            raise ValueError("must be one of enum values ('a_format_was_updated')")
        return value

    @validator('format_inserted')
    def format_inserted_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_format_was_inserted',):
            raise ValueError("must be one of enum values ('a_format_was_inserted')")
        return value

    @validator('format_value_edited')
    def format_value_edited_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_format_value_was_edited',):
            raise ValueError("must be one of enum values ('a_format_value_was_edited')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TrackedFormatEventIdentifierDescriptionPairs:
        """Create an instance of TrackedFormatEventIdentifierDescriptionPairs from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TrackedFormatEventIdentifierDescriptionPairs:
        """Create an instance of TrackedFormatEventIdentifierDescriptionPairs from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TrackedFormatEventIdentifierDescriptionPairs.parse_obj(obj)

        _obj = TrackedFormatEventIdentifierDescriptionPairs.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "format_created": obj.get("format_created"),
            "format_copied": obj.get("format_copied"),
            "format_partially_copied": obj.get("format_partially_copied"),
            "format_downloaded": obj.get("format_downloaded"),
            "format_deleted": obj.get("format_deleted"),
            "format_generic_classification_updated": obj.get("format_generic_classification_updated"),
            "format_specific_classification_updated": obj.get("format_specific_classification_updated"),
            "format_updated": obj.get("format_updated"),
            "format_inserted": obj.get("format_inserted"),
            "format_value_edited": obj.get("format_value_edited")
        })
        return _obj


